==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/QGpCompatibility/src/CompatSrcHodochrone.h <==
/***************************************************************************
**
**  This file is part of QGpCompatibility.
**
**  QGpCompatibility is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  QGpCompatibility is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-11-02
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef COMPATSRCHODOCHRONE_H
#define COMPATSRCHODOCHRONE_H

#include <QGpCoreTools.h>
#include <QGpCoreWave.h>
#include "QGpCompatibilityDLLExport.h"

namespace QGpCompatibility {

/*
class QGPCOMPATIBILITY_EXPORT CompatSrcHodochrone : public QVector<ArrivalTime>, public XMLClass
{
  TRANSLATIONS( "CompatSrcHodochrone" );
public:
  CompatSrcHodochrone() {}
  virtual ~CompatSrcHodochrone() {}

  void setNRec(int n) {resize(n);}
  int nRec() const {return count();}

  ArrivalTime& receiver(int iArr) {return operator[](iArr);}
  const ArrivalTime& receiver(int iArr) const {return operator[](iArr);}

  Point& source() {return _src;}
  double& distance(int iArr) {return receiver(iArr).distance();}
  double& time(int iArr) {return receiver(iArr).time();}
  double& timeDev(int iArr) {return receiver(iArr).timeDev();}

  QString& log() {return _log;}
protected:
  QString _log;
  Point _src;
protected:
  virtual const QString& xml_tagName() const {return xmlSrcHodochroneTag;}
  static const QString xmlSrcHodochroneTag;
  virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
  virtual XMLMember xml_member(XML_MEMBER_ARGS);
  void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
  bool xml_setProperty(XML_SETPROPERTY_ARGS);
};
*/

} // namespace QGpCompatibility

#endif // COMPATSRCHODOCHRONE_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/QGpCompatibility/src/CompatSrcHodochrone.h <==
/***************************************************************************
**
**  This file is part of QGpCompatibility.
**
**  QGpCompatibility is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  QGpCompatibility is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2004-11-02
**  Copyright: 2004-2019
**    Marc Wathelet
**    Marc Wathelet (ULg, Liège, Belgium)
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef COMPATSRCHODOCHRONE_H
#define COMPATSRCHODOCHRONE_H

#include <QGpCoreTools.h>
#include <QGpCoreWave.h>
#include "QGpCompatibilityDLLExport.h"

namespace QGpCompatibility {

/*
class QGPCOMPATIBILITY_EXPORT CompatSrcHodochrone : public VectorList<ArrivalTime>, public XMLClass
{
  TRANSLATIONS( "CompatSrcHodochrone" );
public:
  CompatSrcHodochrone() {}
  virtual ~CompatSrcHodochrone() {}

  void setNRec(int n) {resize(n);}
  int nRec() const {return count();}

  ArrivalTime& receiver(int iArr) {return operator[](iArr);}
  const ArrivalTime& receiver(int iArr) const {return operator[](iArr);}

  Point& source() {return _src;}
  double& distance(int iArr) {return receiver(iArr).distance();}
  double& time(int iArr) {return receiver(iArr).time();}
  double& timeDev(int iArr) {return receiver(iArr).timeDev();}

  QString& log() {return _log;}
protected:
  QString _log;
  Point _src;
protected:
  virtual const QString& xml_tagName() const {return xmlSrcHodochroneTag;}
  static const QString xmlSrcHodochroneTag;
  virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
  virtual XMLMember xml_member(XML_MEMBER_ARGS);
  void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
  bool xml_setProperty(XML_SETPROPERTY_ARGS);
};
*/

} // namespace QGpCompatibility

#endif // COMPATSRCHODOCHRONE_H
